sub

Function sub 

pub fn sub(
    img: DynamicImage,
    lhs: Option<Vec<String>>,
    rhs: Option<Vec<String>>,
    color: Rgb<u8>,
    raw: bool,
) -> RgbaImage
Subtraction blend mode operation. Subtracts the input color RGB from each pixel’s RGB. RGB channels are remappable before operation.

  • img - The image::DynamicImage input to perform the operation on.
  • lhs - Optional vector of Strings to remap the order of the channels of the left-hand side.
  • rhs - Optional vector of Strings to remap the order of the channels of the right-hand side.
  • color - Temporarily based on the Clap RgbColor struct. The right-hand side of the operation.
  • raw - bool, if true, allow for u8 underflow, else, get the absolute value of the operation.